[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# CI/CD 툴을 활용한 DNS Zone Files 관리자동화 구성

> CI/CD 툴을 사용해 DNS Zone 파일적용 및 관리 (GitLab 오픈소스 버전관리 솔루션을 활용하여, 적용/롤백/백업을 진행)


## DNS Server(Bind 9) 구성

이 문서에서는 설치 과정을 다루지않고, 결과적인 설정만 명시

```bash
# cat /etc/named.conf
//
// named.conf
//
// Provided by Red Hat bind package to configure the ISC BIND named(8) DNS
// server as a caching only nameserver (as a localhost DNS resolver only).
//
// See /usr/share/doc/bind*/sample/ for example named configuration files.
//
// See the BIND Administrator's Reference Manual (ARM) for details about the
// configuration located in /usr/share/doc/bind-{version}/Bv9ARM.html

options {
        listen-on port 53 { 127.0.0.1; 61.100.0.135; };
        #listen-on-v6 port 53 { ::1; };
        version         "not";
        tcp-clients     3000;
        recursive-clients 300000;
        directory       "/var/named";
        dump-file       "/var/named/data/cache_dump.db";
        statistics-file "/var/named/data/named_stats.txt";
        memstatistics-file "/var/named/data/named_mem_stats.txt";
        recursing-file  "/var/named/data/named.recursing";
        secroots-file   "/var/named/data/named.secroots";
        notify yes;
        also-notify     { 61.100.0.152; 61.100.0.158; };
        allow-transfer  { 61.100.0.152; 61.100.0.158; };
        allow-recursion { localhost; 127.0.0.1; 61.100.0.128/25; 192.168.1.0/24; };

        /*
         - If you are building an AUTHORITATIVE DNS server, do NOT enable recursion.
         - If you are building a RECURSIVE (caching) DNS server, you need to enable
           recursion.
         - If your recursive DNS server has a public IP address, you MUST enable access
           control to limit queries to your legitimate users. Failing to do so will
           cause your server to become part of large scale DNS amplification
           attacks. Implementing BCP38 within your network would greatly
           reduce such attack surface
        */
        recursion yes;

        dnssec-enable yes;
        dnssec-validation yes;

        /* Path to ISC DLV key */
        bindkeys-file "/etc/named.root.key";

        managed-keys-directory "/var/named/dynamic";

        pid-file "/run/named/named.pid";
        session-keyfile "/run/named/session.key";
};

logging {
             channel default_debug {
                file "data/named.run";
                severity dynamic;
             };

             channel "misc" {
                    file "/var/log/named/misc.log" versions 10 size 10m;
                    print-time YES;
                    print-severity YES;
                    print-category YES;
             };

             channel "query" {
                    file "/var/log/named/query.log" versions 10 size 10m;
                    print-time YES;
                    print-severity NO;
                    print-category NO;
             };

             category "default" { "misc"; };
             category "queries" { "query"; };
        };

zone "." IN {
        type hint;
        file "named.ca";
};

include "/etc/named.rfc1912.zones";
include "/etc/named.root.key";
include "/var/named/zones/hjh.conf";

```

> CI/CD 요소는 /var/named/zones/hjh.conf


## /var/named/zones/hjh.conf 내역

```bash
# cat /var/named/zones/hjh.conf
zone "freehongs.net" IN {type master; file "/var/named/zones/freehongs.net"; };
zone "hongsnet.net" IN {type master; file "/var/named/zones/hongsnet.net"; };
```

## .gitlab-ci.yml 내역

```bash
# cat .gitlab-ci.yml
stages:
  - deploy
  - backup

variables:
  GIT_STRATEGY: clone
  GIT_SSL_NO_VERIFY: "1"
  TARGET_BIND_DIR: /var/named/zones/
  TARGET_TB2_DIR: /GIT/hongsnet/UPLOAD
  TARGET_TB3_DIR: /GIT/hongsnet/UPLOAD

dns_hongsnet:
  stage: deploy
  only:
    - master
  script:
   - rsync -ar --exclude=.git --exclude=README.md --delete ${CI_PROJECT_DIR}/ ${TARGET_BIND_DIR}
   - chown -R named.named /var/named/zones
   - rndc reload
  tags:
   - dns135

tb2:
  stage: backup
  only:
    - master
  before_script:
   - (if [[ ! -d ${TARGET_TB2_DIR} ]]; then mkdir -p ${TARGET_TB2_DIR}; fi);
  script:
   - rsync -ar --delete ${CI_PROJECT_DIR}/* ${TARGET_TB2_DIR}/
  tags:
   - tb2

tb3:
  stage: backup
  only:
    - master
  before_script:
   - (if [[ ! -d ${TARGET_TB3_DIR} ]]; then mkdir -p ${TARGET_TB3_DIR}; fi);
  script:
   - rsync -ar --delete ${CI_PROJECT_DIR}/* ${TARGET_TB3_DIR}/
  tags:
   - tb3
```

